@@ -322,6 +322,11 @@ class InventoryBatchHandler(BatchHandler):
             self.add_row(batch, row)
             return row
 
+        # if we made it this far, then we did not find the product,
+        # *and* we did not add the unknown product to batch.  so just
+        # throw an error so caller logic can handle that
+        raise ValueError("Product not found!")
+
     def refresh(self, batch, progress=None):
         batch.total_cost = 0
 
