@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -63,7 +63,7 @@ class AlbertsInvoiceParser(InvoiceParser):
         reader = csv.DictReader(csv_file)
         for data in reader:
 
-            row = model.VendorInvoiceRow()
+            row = model.VendorInvoiceBatchRow()
             row.item_entry = data['UPCPLU'].replace('-', '').replace(' ', '')
             row.upc = GPC(row.item_entry)
             row.vendor_code = data['ItemNumber']
