@@ -157,10 +157,16 @@ class ImporterEmail(Email):
     def get_handler(self, config):
         return load_object(self.handler_spec)(config)
 
-    def get_default_subject(self):
-        handler = self.get_handler(self.config)
-        return "Changes for {} -> {}".format(
-            handler.host_title, handler.local_title)
+    def get_default_subject(self, **data):
+        host_title = data.get('host_title')
+        local_title = data.get('local_title')
+        if not (host_title and local_title):
+            handler = self.get_handler(self.config)
+            if not host_title:
+                host_title = handler.host_title
+            if not local_title:
+                local_title = handler.local_title
+        return "Changes for {} -> {}".format(host_title, local_title)
 
     def sample_data(self, request):
         handler = self.get_handler(request.rattail_config)
@@ -193,6 +199,22 @@ class ImporterEmail(Email):
         }
 
 
+class rattail_export_rattail_updates(ImporterEmail):
+    """
+    Sent when a full Rattail -> Rattail data export involves changes.
+    """
+    handler_spec = 'rattail.importing.rattail:FromRattailToRattailExport'
+    abstract = False
+
+
+class rattail_import_rattail_updates(ImporterEmail):
+    """
+    Sent when a full Rattail -> Rattail data import involves changes.
+    """
+    handler_spec = 'rattail.importing.rattail:FromRattailToRattailImport'
+    abstract = False
+
+
 class rattail_import_versions_updates(ImporterEmail):
     """
     Sent when a "version catch-up" import is performed, which involves changes.
