@@ -144,7 +144,7 @@ class ProblemReportHandler(object):
                                 progress=self.progress)
 
         problems = report.find_problems(**kwargs)
-        log.debug("found %s problems", len(problems))
+        log.info("found %s problems", len(problems))
         if problems:
             self.send_problem_report(report, problems)
 
