@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -45,7 +45,7 @@ except ImportError: # pragma no cover
 NOTSET = object()
 
 
-def capture_output(command):
+def capture_output(*args, **kwargs):
     """
     Runs ``command`` and returns any output it produces.
     """
@@ -53,8 +53,12 @@ def capture_output(command):
     # the ``hg`` command.  However, we must pipe *all* handles in order to
     # prevent issues when running as a GUI but *from* the Windows console.  See
     # also: http://bugs.python.org/issue3905
-    kwargs = dict(stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-    output = subprocess.Popen(command, **kwargs).communicate()[0]
+    kwargs.update({
+        'stdin': subprocess.PIPE,
+        'stdout': subprocess.PIPE,
+        'stderr': subprocess.PIPE,
+    })
+    output = subprocess.Popen(*args, **kwargs).communicate()[0]
     return output
 
 
